============
Contributing
============

Contributions are welcome, and they are greatly appreciated! Every
little bit helps, and credit will always be given.

Documentation
-------------

eldl_ could always use more documentation, whether as part of the
official docs, in docstrings, or even on the web in blog posts,
articles, and such.

Feedback
--------

The best way to send feedback is to `file an issue`_.

Bug Reports
~~~~~~~~~~~

When reporting a bug, please include:

* Your operating system name and version.

* Any details about your local setup that might be helpful in troubleshooting.
  (e.g., Python version)

* Detailed steps to reproduce the bug.

Feature Requests
~~~~~~~~~~~~~~~~

When proposing a feature, please include:

* Explain in detail how it would work.

* Keep the scope as narrow as possible, to make it easier to implement.

* Remember that this is a volunteer-driven project, and that code contributions
  are welcome :)

.. _file an issue: https://gitlab.com/ugognw/python-comp-chem-utils/-/issues
.. _eldl: https://github.com/ugognw/eldl
